/***********************************************************************************************************************************
Stanza Delete Command
***********************************************************************************************************************************/
#ifndef COMMAND_STANZA_DELETE_H
#define COMMAND_STANZA_DELETE_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Process stanza-delete
FN_EXTERN void cmdStanzaDelete(void);

#endif
